package com.ruoyi.ems.service;

import java.util.List;
import com.ruoyi.ems.domain.EmsFacsFlowRel;

/**
 * 能源设施能流关系Service接口
 *
 * @author ruoyi
 * @date 2024-07-10
 */
public interface IEmsFacsFlowRelService {
    /**
     * 查询能源设施能流关系
     *
     * @param id 能源设施能流关系主键
     * @return 能源设施能流关系
     */
    EmsFacsFlowRel selectEmsFacsFlowRelById(Long id);

    /**
     * 查询能源设施能流关系列表
     *
     * @param emsFacsFlowRel 能源设施能流关系
     * @return 能源设施能流关系集合
     */
    List<EmsFacsFlowRel> selectEmsFacsFlowRelList(EmsFacsFlowRel emsFacsFlowRel);

    /**
     * 新增能源设施能流关系
     *
     * @param emsFacsFlowRel 能源设施能流关系
     * @return 结果
     */
    int insertEmsFacsFlowRel(EmsFacsFlowRel emsFacsFlowRel);

    /**
     * 修改能源设施能流关系
     *
     * @param emsFacsFlowRel 能源设施能流关系
     * @return 结果
     */
    int updateEmsFacsFlowRel(EmsFacsFlowRel emsFacsFlowRel);

    /**
     * 批量删除能源设施能流关系
     *
     * @param ids 需要删除的能源设施能流关系主键集合
     * @return 结果
     */
    int deleteEmsFacsFlowRelByIds(Long[] ids);

    /**
     * 删除能源设施能流关系信息
     *
     * @param id 能源设施能流关系主键
     * @return 结果
     */
    int deleteEmsFacsFlowRelById(Long id);
}
